# ---------------------- #
#     Removing ID 1      #
# ---------------------- #
# Used as test case.
data <- subset(data, subject_id > 1)

# ---------------------- #
#   Renaming variables   #
# ---------------------- #
data <- upData(data, rename=c('ed_arrivetime' = 'ed_visittime',
                              'cathlab_time' = 'pt_arrival_cath_lab_time',
                              'baloontime' = 'balloontime',
                              'interventionstart' = 'intervention_time',
                              'ef_duringhosp_2' = 'ef_during_hosp',
                              'efduringhosp_2' = 'ef_during_hosp_ind',
                              'efduringhosp_2.factor' = 'ef_during_hosp_ind.factor',
                              'duringhosp_efdate' = 'ef_during_hosp_date',
                              'efprior' = 'ef_prior_ind',
                              'efprior.factor' = 'ef_prior_ind.factor',
                              'prioref_date' = 'ef_prior_date',
                              'prioref_range' = 'ef_prior_range',
                              'efpostdisch' = 'ef_post_discharge_ind',
                              'efpostdisch.factor' = 'ef_post_discharge_ind.factor',
                              'efpostdischarge' = 'ef_post_discharge',
                              'efpostdisch_range' = 'ef_post_discharge_range',
                              'efpost_date' = 'ef_post_discharge_date',
                              'ef_range_during' = 'ef_during_hosp_range'))

# ---------------------- #
#    Formatting dates    #
# ---------------------- #
# Just date variables
date_vars <- grep('date',names(data), value=TRUE)
sub_time_vars <- grep('time', date_vars, value=TRUE)
date_vars <- date_vars[-which(date_vars %in% sub_time_vars)]
date_vars <- c(date_vars, 'dem_dob')

data[,date_vars] <- map_df(.x = data[,date_vars],
                           .f = function(y){
                              as.Date(y, format='%Y-%m-%d')
                           } )

# Date/time variables
date_time_vars <- grep('datetime', names(data), value=TRUE)

data[,date_time_vars] <- map_df(.x = data[,date_time_vars],
                                .f = function(y){
                                   as.POSIXct(y, format='%Y-%m-%d %H:%M', tz='GMT')
                                } )

# Pasting together date and time vars and then formatting
time_vars <- grep('time',names(data), value=TRUE)
time_vars <- time_vars[-which(time_vars %in% date_time_vars)]

date_vars2 <- time_vars2 <- NULL
for(i in 1:length(time_vars)){
    tmp <- gsub('time', 'date', time_vars[i])
    if(tmp %in% names(data)){
        date_vars2 <- c(date_vars2, tmp)
        time_vars2 <- c(time_vars2, time_vars[i])
    }
}

date_time_vars2 <- paste(date_vars2, '_time',sep='')
for(i in 1:length(date_vars2)){
    data[[date_time_vars2[i]]] <- as.POSIXct(paste(data[[date_vars2[i]]], data[[time_vars2[i]]], sep=' '), 
                                             format='%Y-%m-%d %H:%M', tz='GMT')
}


# ------------------------- #
#  Diagnostic ECG date/time #
# ------------------------- #
# Need to write code to determine date/time of diagnostic ECG.  The diagnostic ECG could be at one of the following times:
# a)  None
# b)  Receiving Hospital:  ecg_date/ecg_time
# c)  Receiving Hospital Follow Up:  ecg_date_2/ecg_time_2
# d)  Outside Hospital ED:  outedecg_datetime
# e)  Clinic Provider:  clinicecg_datetime
# f)  EMS to Receiving Hospital:  ambecg_datetime
# g)  EMS to Outside Transferring Hospital:  outemsecg_datetime

which_1 <- which(data$diagecg == 1)
which_6 <- which(data$diagecg == 6)
which_2 <- which(data$diagecg == 2)
which_3 <- which(data$diagecg == 3)
which_4 <- which(data$diagecg == 4)
which_5 <- which(data$diagecg == 5)

data$diag_ecg_date_time <- NA
if(length(which_1) > 0){
   data$diag_ecg_date_time[which_1] <- as.POSIXct(paste(data$ecg_date[which_1], data$ecg_time[which_1],sep=' '),format='%Y-%m-%d %H:%M', tz='GMT')
}
if(length(which_6) > 0){
   data$diag_ecg_date_time[which_6] <- as.POSIXct(paste(data$ecg_date_2[which_6], data$ecg_time_2[which_6], sep=' '),format='%Y-%m-%d %H:%M', tz='GMT')
}
if(length(which_2) > 0){
   data$diag_ecg_date_time[which_2] <- data$outedecg_datetime[which_2]
}
if(length(which_3) > 0){
   data$diag_ecg_date_time[which_3] <- data$clinicecg_datetime[which_3]
}
if(length(which_4) > 0){
   data$diag_ecg_date_time[which_4] <- data$ambecg_datetime[which_4]
}
if(length(which_5) > 0){
   data$diag_ecg_date_time[which_5] <- data$outemsecg_datetime[which_5]
}
data$diag_ecg_date_time <- as.POSIXct(data$diag_ecg_date_time, format='%Y-%m-%d %H:%M', origin='1970-01-01 00:00',tz='GMT')

data$diag_ecg_date <- as.Date(data$diag_ecg_date_time, format='%Y-%m-%d')


# ----------------------------------- #
#   Estimating dates for some times   #
# ----------------------------------- #
# Per Maya:
# a)  the Cath lab activation time should use the diagnostic ECG date
# b)  time of arrival of the patient to the cath lab, guide wire time, and balloon time should use the STEMI intervention date
data$ed_cathlab_datetime <- ifelse(!is.na(data$ed_cathlabtime) & !is.na(data$diag_ecg_date),paste(data$diag_ecg_date, data$ed_cathlabtime, sep=' '),NA)
data$ed_cathlab_datetime <- as.POSIXct(data$ed_cathlab_datetime, format='%Y-%m-%d %H:%M', tz='GMT')

data$pt_arrival_cath_lab_datetime <- ifelse(!is.na(data$intervention_date) & !is.na(data$pt_arrival_cath_lab_time),
                                            paste(data$intervention_date, data$pt_arrival_cath_lab_time, sep=' '),NA)
data$pt_arrival_cath_lab_datetime <- as.POSIXct(data$pt_arrival_cath_lab_datetime, format='%Y-%m-%d %H:%M')

data$guidewire_datetime <- ifelse(!is.na(data$intervention_date) & !is.na(data$guidewire),
                                            paste(data$intervention_date, data$guidewire, sep=' '),NA)
data$guidewire_datetime <- as.POSIXct(data$guidewire_datetime, format='%Y-%m-%d %H:%M')

data$balloon_datetime <- ifelse(!is.na(data$intervention_date) & !is.na(data$balloontime),
                                            paste(data$intervention_date, data$balloontime, sep=' '),NA)
data$balloon_datetime <- as.POSIXct(data$balloon_datetime, format='%Y-%m-%d %H:%M')
